@@ -1,8 +1,7 @@
 package Class::MakeMethods::Template::Flyweight;
 
-use Class::MakeMethods::Template::InsideOut;
+use Class::MakeMethods::Template::InsideOut '-isasubclass';
 
-@ISA = "Class::MakeMethods::Template::InsideOut";
 $VERSION = 1.008;
 
 sub new { { '-import' => { 'Template::Scalar:new' => '*' } } }
