@@ -38,8 +38,7 @@ The MakeMethods subclass provides accessor methods that search an inheritance tr
 
 package Class::MakeMethods::Template::Inheritable;
 
-use Class::MakeMethods::Template::Generic;
-BEGIN { @ISA = qw( Class::MakeMethods::Template::Generic ); }
+use Class::MakeMethods::Template::Generic '-isasubclass';
 
 $VERSION = 1.008;
 use strict;
