@@ -1,8 +1,7 @@
 package Class::MakeMethods::Template::Struct;
 
-use Class::MakeMethods::Template::Array;
+use Class::MakeMethods::Template::Array '-isasubclass';
 
-@ISA = "Class::MakeMethods::Template::Array";
 $VERSION = 1.008;
 
 1;
